<?php 

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Model Class
 *
 * Handles generic plugin functionality.
 *
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 */
class Wpsd_Model {
	
	
	public function __construct() {
		
	}
	
	/**
	 * Escape Tags & Slashes
	 *
	 * Handles escapping the slashes and tags
	 *
	 * @package  WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
   
	public function wpsd_escape_attr($data){
		return esc_attr(stripslashes($data));
	}
	
	/**
	 * Strip Slashes From Array
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
   
	public function wpsd_escape_slashes_deep($data = array(),$flag=false){
			
		if($flag != true) {
			$data = $this->wpsd_nohtml_kses($data);
		}
		$data = stripslashes_deep($data);
		return $data;
	}
	
	/**
	 * Strip Html Tags 
	 * 
	 * It will sanitize text input (strip html tags, and escape characters)
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function wpsd_nohtml_kses($data = array()) {
		
		
		if ( is_array($data) ) {
			
			$data = array_map(array($this,'wpsd_nohtml_kses'), $data);
			
		} elseif ( is_string( $data ) ) {
			
			$data = wp_filter_nohtml_kses($data);
		}
		
		return $data;
	}	
	
	/**
	 * Count down timer script
	 * 
	 * Handles to show count down timer when 
	 * deal is enabaled
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */ 
	public function wpsd_getting_countdown_script($date) {
		
		$date = strtotime($date);
		
		return "<script type='text/javascript'>
						
						var year='".date('Y',$date)."';
						
						var month='".date('m',$date)."';
							
						var day='".date('d',$date)."';
						
						var hour='".date('H',$date)."';
						
						var minute='".date('i',$date)."';
						
						var dealstimeflag = '1';
						
						var currenttime = '".date('F d, Y H:i:s', time())."';
						
						var today = new Date(currenttime);
						
			 	</script>";
	}
	
	/**
 	 * Return Time Left
 	 * 
 	 * Handles to return time string 
 	 * 
 	 * @package WooCommerce WP Social Deals
 	 * @since 1.0.0
 	 */
	public function wpsd_seconds_to_time($inputSeconds) {

	    $secondsInAMinute = 60;
	    $secondsInAnHour  = 60 * $secondsInAMinute;
	    $secondsInADay    = 24 * $secondsInAnHour;
	
	    // extract days
	    $days = floor($inputSeconds / $secondsInADay);
	
	    // extract hours
	    $hourSeconds = $inputSeconds % $secondsInADay;
	    $hours = floor($hourSeconds / $secondsInAnHour);
	
	    // extract minutes
	    $minuteSeconds = $hourSeconds % $secondsInAnHour;
	    $minutes = floor($minuteSeconds / $secondsInAMinute);
	
	    // extract the remaining seconds
	    $remainingSeconds = $minuteSeconds % $secondsInAMinute;
	    $seconds = ceil($remainingSeconds);
	
	    if ($days < 10) { $days = '0'.$days; }
	    if ($minutes < 10) { $minutes = '0'.$minutes; }
	    if ($hours < 10) { $hours = '0'.$hours; }
	    if ($seconds < 10) { $seconds = '0'.$seconds; }
	    
	    $since = '';
	    $since .= $days <= 1 	? $days.__( ' day ','wpsd' ) 	: $days.__( ' days ','wpsd' );
	    $since .= $hours <= 1 	? $hours.__( ' hr ','wpsd' ) 	: $hours.__( ' hrs ','wpsd' );
	    $since .= $minutes <= 1 ? $minutes.__( ' min ','wpsd' )	: $minutes.__( ' mins ','wpsd' );
	    $since .= $seconds <= 1 ? $seconds.__( ' sec ','wpsd' ) 	: $seconds.__( ' secs ','wpsd' );
	    
	    // return the final array
	    /*$obj = array(
	        'd' => (int) $days,
	        'h' => (int) $hours,
	        'm' => (int) $minutes,
	        's' => (int) $seconds,
	    );*/
	    return $since;
	}

	/**
 	 * Return Start Date
 	 * 
 	 * Handles to return start date
 	 * 
 	 * @package WooCommerce WP Social Deals
 	 * @since 1.0.0
 	 */
	public function wpsd_get_start_date( $post_id ) {
		
		$product_type = $this->wpsd_get_product_type( $post_id );
		if( strtolower($product_type) == 'variable' || strtolower($product_type) == 'grouped' ) { // check product type is variable or grouped
		
			$start_date = get_post_meta( $post_id, '_wpsd_start_date', true );
			
		} else {
			
			$start_date = get_post_meta( $post_id, '_sale_price_dates_from', true );
			
		}
		$start_date = !empty($start_date) ?  date_i18n( 'Y-m-d H:i:s', $start_date ) : '';
		
		return $start_date;
	}
	
	/**
 	 * Return End Date
 	 * 
 	 * Handles to return end date
 	 * 
 	 * @package WooCommerce WP Social Deals
 	 * @since 1.0.0
 	 */
	public function wpsd_get_end_date( $post_id ) {
		
		$product_type = $this->wpsd_get_product_type( $post_id );
		if( strtolower($product_type) == 'variable' || strtolower($product_type) == 'grouped' ) { // check product type is variable or grouped
			
			$end_date = get_post_meta( $post_id, '_wpsd_end_date', true );
			
		} else {
			
			$end_date = get_post_meta( $post_id, '_sale_price_dates_to', true );
		}
		$end_date = !empty($end_date) ?  date_i18n( 'Y-m-d H:i:s', $end_date ) : '';
		
		return $end_date;
	}
	
	/**
 	 * Return Product Type
 	 * 
 	 * Handles to return product type
 	 * 
 	 * @package WooCommerce WP Social Deals
 	 * @since 1.0.0
 	 */
	public function wpsd_get_product_type( $post_id ) {
		
		if ( $terms = wp_get_object_terms( $post_id, 'product_type' ) ) {
			
			$product_type = sanitize_title( current( $terms )->name );
			
		} else {
			
			$product_type = 'simple';
		}
		
		return $product_type;
	}
	
	/**
 	 * Return Default Variation id
 	 * 
 	 * Handles to return default variation id
 	 * 
 	 * @package WooCommerce WP Social Deals
 	 * @since 1.0.0
 	 */
	public function wpsd_get_default_variation_id() {
		
		global $product;
		
		$default_variation_id = '';
		
		//if product type is variable
		if( strtolower($product->product_type) == 'variable' ) {
		
			// get variation ids
			$variation_data = $product->get_children();
			
			// get default variation attributes
			$default_attribute = $product->get_variation_default_attributes();
			
			foreach ( $variation_data as $var_key => $variation_id ) {
				
				$variation = $product->get_child( $variation_id ); 
		
				// get particular variation attributes
		        $variation_attributes = $variation->get_variation_attributes();
				
	        	$variation_flag = 0;
		        foreach ($default_attribute as $attr_key => $attr_value ) {
			    
			        if( isset($variation_attributes['attribute_'.$attr_key]) && $variation_attributes['attribute_'.$attr_key] == $attr_value ) {
			        	$variation_flag = $variation_flag + 1;
			        }
		        }
		        if( $variation_flag == count($default_attribute) && $variation_flag == count($variation_attributes) ) { // check default variation are match
		        	$default_variation_id = $variation_id;
		        	break;
		        }
		       
			}
		}
		return $default_variation_id;
	}
	
}
?>